@@ -2,7 +2,7 @@ package goto::file;
 use strict;
 use warnings;
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 use Filter::Util::Call qw/filter_add filter_read/;
 
@@ -64,14 +64,18 @@ sub filter {
     }
 
     my $lines = $self->{lines};
-    my $fh    = $self->{fh};
+    my $fh = $self->{fh};
 
     my $line;
     if (@$lines) {
         chomp($line = shift @$lines);
         $line .= "\n";
     }
-    elsif ($fh) {
+    elsif($fh) {
+        # We do this to prevent ', <$fh> at line #' being appended to
+        # exceptions and warnings.
+        local $.;
+
         $line = <$fh>;
     }
 
